@@ -1,8 +1,8 @@
 var node_8c =
 [
-    [ "param_array", "structparam__array.html", "structparam__array" ],
     [ "pw_node_add_listener", "node_8c.html#a2bb3fca14d3b5749df798bc517b02ae8", null ],
     [ "pw_node_find_port", "node_8c.html#ae457b2a0a17339a0ea724fb7248792d3", null ],
+    [ "pw_node_for_each_param", "node_8c.html#ab8554682ed331de13cc8a0632eeda3fe", null ],
     [ "pw_node_for_each_port", "node_8c.html#aa54a8f52d35bd9521ceb32dc7e950a85", null ],
     [ "pw_node_get_core", "node_8c.html#aae589dae6a27dd5f2235d7108e3e8d9c", null ],
     [ "pw_node_get_free_port_id", "node_8c.html#ae040b5eb03ad653e474e1ef547adeeed", null ],
@@ -12,9 +12,11 @@ var node_8c =
     [ "pw_node_get_properties", "node_8c.html#a898e5e0afefe00d5154c9c1c64f84c53", null ],
     [ "pw_node_get_user_data", "node_8c.html#a13e057acc81dae7a8deb71a65ef326fb", null ],
     [ "pw_node_is_active", "node_8c.html#ae8556f1a5560c142b586096ad32844b5", null ],
+    [ "pw_node_is_enabled", "node_8c.html#a744c2f726f9305f6b04d3e92eb4232b6", null ],
     [ "pw_node_new", "node_8c.html#a870165a7fc624281df45824030c476a6", null ],
     [ "pw_node_register", "node_8c.html#a544f3c8fc58776843ac1315cc1dfeb38", null ],
     [ "pw_node_set_active", "node_8c.html#a2502272c5765d1f2dab5afd890c05f62", null ],
+    [ "pw_node_set_enabled", "node_8c.html#a2c39fd06d78e6f0146e56a4571262fa9", null ],
     [ "pw_node_set_implementation", "node_8c.html#a442d47d3b1668d9f57ade6109281a8c7", null ],
     [ "pw_node_update_properties", "node_8c.html#a01db9fe936ffca5e133a4f7acb699ca1", null ]
 ];
\ No newline at end of file
