@@ -4,15 +4,17 @@ var remote_8c =
     [ "pw_remote_connect", "remote_8c.html#a2d834fb0fdcb7e2174b9c156bcc3fe69", null ],
     [ "pw_remote_connect_fd", "remote_8c.html#a92da67f8a9313c37504044486a1d7cb0", null ],
     [ "pw_remote_destroy", "remote_8c.html#a512639c335f32485de2291f03ae03cdc", null ],
-    [ "pw_remote_disconnect", "remote_8c.html#a8e9f9d92e67bc9769b9fccf53af653a4", null ],
+    [ "pw_remote_disconnect", "remote_8c.html#a90de30b9f1762e327e05bf8d6a0047a4", null ],
     [ "pw_remote_export", "remote_8c.html#a5ea2b8b2674320fb320c5b2c71b0bac2", null ],
     [ "pw_remote_find_proxy", "remote_8c.html#af0a388b2eb3bab3047517754aad8702f", null ],
     [ "pw_remote_get_core", "remote_8c.html#aea761b0969728a0b0e226b568c247f58", null ],
     [ "pw_remote_get_core_info", "remote_8c.html#a092bf29d1cd7cc32233a3daee0764930", null ],
     [ "pw_remote_get_core_proxy", "remote_8c.html#a953d3df17ce9c26bcd790d1b4a5b33d7", null ],
+    [ "pw_remote_get_properties", "remote_8c.html#ad9e26cfa589784bec881c01b34a5444b", null ],
     [ "pw_remote_get_state", "remote_8c.html#aad3cbf91014d891f30d33c52fc63f7fb", null ],
     [ "pw_remote_get_user_data", "remote_8c.html#a345eb6d633bbd8dd6e5f4089a66601db", null ],
     [ "pw_remote_new", "remote_8c.html#a64ccc7fa45e62f41c95942b938a3407b", null ],
     [ "pw_remote_state_as_string", "remote_8c.html#a83445c8ddb750ea51175e2b1d955bb6e", null ],
-    [ "pw_remote_update_state", "remote_8c.html#a52ece7f0406054bbb273fb9a79068200", null ]
+    [ "pw_remote_steal_fd", "remote_8c.html#a2449ad8295ff02c72c25ab34feaa0324", null ],
+    [ "pw_remote_update_state", "remote_8c.html#ad63bfda38e8a40c3c37b44ef82dafd2e", null ]
 ];
\ No newline at end of file
